<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://lin3s.com
 * @since      1.0.0
 *
 * @package    Alexandria_Conversation_Builder
 * @subpackage Alexandria_Conversation_Builder/admin/partials
 */


?>

<div class="wrap">

	<h1 class="wp-heading-inline">
		<?php _e('Añadir/Editar Nuevo Quizz', 'alexandria-mail-builder')?>
	</h1>

	<ul class="header-links-list">

		<li>
			<a href="admin.php?page=alexandria-mail-builder-quizzes-list">
				<?php _e('Volver a los quizzes', 'alexandria-mail-builder') ?>
			</a>
		</li>

		<?php if(!empty($quiz->id)):?>

			<span>|</span>
			<li>
				
				<a href="admin.php?page=alexandria-mail-builder-questions&quiz_id=<?php echo $quiz->id?>">
					<?php _e('Administar preguntas', 'alexandria-mail-builder')?>
				</a>
			</li>

		<?php endif;?>

	</ul>

	<hr class="wp-header-end">
	
	<form id="alexandria-quiz-form" method="post">

		<h2 class="title"><?php _e('General', 'alexandria-mail-builder')?></h2>

		<table class="form-table fixed">
			<tbody>

				<tr class="form-required">

					<th scope="row">
						<label for="title">
							<?php _e('Título del Quiz', 'alexandria-mail-builder')?>
						</label>
					</th>

					<td>
						<input id="title" name="title" type="text" size="90" value="<?php echo stripslashes(@$quiz->title)?>" class="required"/>
					</td>

				</tr>

				<tr class="form-required">

					<th scope="row">
						<label for="publish_state">
							<?php _e('Estado del Quizz', 'alexandria-mail-builder')?>
						</label>
					</th>
					<td>
						<fieldset>
							<legend class="screen-reader-text">
								<span><?php _e('Estado del Quizz', 'alexandria-mail-builder')?></span>
								<input type="hidden" name="old_publish_state" value="<?php echo @$quiz->publish_state; ?>">
							</legend>
							<label>
								<input type="radio" name="publish_state" value="0" <?php echo @$quiz->publish_state == '0' ? 'checked' : ''; ?>/>
								<span class="date-time-text"><?php echo _e('Borrador', 'alexandria-mail-builder'); ?></span>
								<p><?php _e('Guardar quiz como borrador.', 'alexandria-mail-builder')?></p>
							</label>
							<br>
							<label>
								<input type="radio" name="publish_state" value="1" <?php echo @$quiz->publish_state == '1' ? 'checked' : ''; ?> />
								<span class="date-time-text"><?php echo _e('Privado', 'alexandria-mail-builder'); ?></span>
								<p><?php _e('Solo visible para los administradores y editores del sitio.', 'alexandria-mail-builder')?></p>
							</label>
							<br>
							<label>
								<input type="radio" name="publish_state" value="2" <?php echo @$quiz->publish_state == '2' ? 'checked' : ''; ?> />
								<span class="date-time-text"><?php echo _e('Publico', 'alexandria-mail-builder'); ?></span>
								<p><?php _e('Visible para todos', 'alexandria-mail-builder')?></p>
							</label>
						</fieldset>

					</td>
				</tr>

				<tr>
					<th scope="row">
						<label for="comments">
							<?php _e('Permitir Comentarios', 'alexandria-mail-builder')?>
						</label>
					</th>
					<td>
						<input type="checkbox" name="comments" value="1" <?php echo @$quiz->comments == '1' ? 'checked' : ''; ?>/>
						<span><?php _e('Permitir comentarios de Wordpress.', 'alexandria-mail-builder')?></span>
					</td>
				</tr>

				<tr>
					<th scope="row">
						<label for="duration">
							<?php _e('Duración estimada', 'alexandria-mail-builder')?>
						</label>
					</th>
					<td>
						<input type="time" name="duration" step="1" value="<?php echo @$quiz->duration; ?>" />
					</td>
				</tr>

				<tr>
					<th scope="row">
						<label for="category_id">
							<?php _e('Categoría', 'alexandria-mail-builder')?>
						</label>
					</th>

					<td>

						<select name="category_id" id="quiz-category">

							<option value="0">
								<?php _e('Elija una Categoría', 'alexandria-mail-builder') ?>
							</option>

							<?php if(!empty($categories)):?>

								<?php foreach ($categories as $category) { ?>
									<option value="<?php echo $category->id; ?>" <?php $category->name == @$quiz_category->name ? '' : 'selected'; ?>><?php echo $category->name; ?></option>
								<?php	}
								?>

							<?php endif; ?>

						</select>

					</td>
				</tr>

			</tbody>

		</table>

		<h2 class="title"><?php _e('Otras opciones', 'alexandria-mail-builder')?></h2>

		<table class="form-table fixed">

			<tbody>
				<tr>
					<th scope="row">
						<label for="thumbnail_summary">
							<?php _e('Descripción de la miniatura', 'alexandria-mail-builder')?>
						</label>
					</th>
					<td>
						<input type="text" size="90" name="thumbnail_summary" value="<?php echo @$quiz->thumbnail_summary; ?>" />
						<p class="description">
							<?php _e('Esta es la frase que aparece en la miniatura del Quizz en el grid de todos los Quizzes.(max.20 palabras)', 'alexandria-mail-builder'); ?>
						</p>
					</td>			
				</tr>

				<tr>
					<th scope="row">
						<label for="theme_color">
							<?php _e('Color del Quizz', 'alexandria-mail-builder')?>
						</label>
					</th>
					<td>

						<input type="text" value="<?php echo @$quiz->theme_color; ?>" class="quizz-theme-color-picker" data-default-color="#effeff" name="theme_color"/>
						<p class="description">
							<?php _e('El color principal de la pagina del Quizz en la web.', 'alexandria-mail-builder'); ?>
						</p>
					</td>
				</tr>

				<tr>
					<th scope="row">
						<label for="intro_text">
							<?php _e('Texto introductorio', 'alexandria-mail-builder')?>
						</label>
					</th>
					<td>
						<textarea name="intro_text" id="intro_text"><?php echo esc_textarea(@$quiz->intro_text) ?></textarea>
						<p class="description">
							<?php _e('Texto que aparece en la cabecera de la pagina del Quiz.', 'alexandria-mail-builder'); ?>
						</p>
					</td>
				</tr>

				<tr>
					<th scope="row">
						<label for="description_text">
							<?php _e('Texto descriptivo', 'alexandria-mail-builder')?>
						</label>
					</th>
					<td>
						<textarea name="description_text" id="description_text"><?php echo esc_textarea(@$quiz->description_text) ?></textarea>
						<p class="description">
							<?php _e('Texto que aparece en el cuerpo de la pagina del Quiz.', 'alexandria-mail-builder'); ?>
						</p>
					</td>
				</tr>

				<tr>
					<th scope="row">
						<label>
							<?php _e('Imagen destacada del Quizz.', 'alexandria-mail-builder')?>
						</label>
					</th>

					<td>

						<div id="alexandria-image-uploader">
							<input id="media_title_text" type="hidden" value="<?php _e('Seleccione o suba la imagen de su elección', 'alexandria-mail-builder') ?>">
							<input id="media_text_button" type="hidden" value="<?php _e('Usar esta imagen', 'alexandria-mail-builder') ?>">

							<?php if( $image = wp_get_attachment_image_src( @$quiz->image_id ) ) { ?>

								<a href="javascript:void(0)" class="upload-custom-img hidden button-primary">
									<?php echo _e('Subir imagen', 'alexandria-mail-builder'); ?>
								</a>

								<a href="javascript:void(0)" class="delete-custom-img button-primary">
									<?php echo _e('Eliminar imagen', 'alexandria-mail-builder'); ?>
								</a>

								<input id="image_url" type="hidden" name="image_url" value="' . esc_url($image_url) . '">
								<input id="image_id" type="hidden" name="image_id" value="' . $image_id . '">

							<?php } else { ?>

								<a href="javascript:void(0)" class="upload-custom-img button-primary">
									<?php echo _e('Subir imagen', 'alexandria-mail-builder'); ?>
								</a>

								<a href="javascript:void(0)" class="delete-custom-img hidden button-primary">
									<?php echo _e('Eliminar imagen', 'alexandria-mail-builder'); ?>
								</a>

								<input id="image_url" type="hidden" name="image_url" value="">
								<input id="image_id" type="hidden" name="image_id" value="">

							<?php } ?>
						</td>
					</tr>

					<tr>
						<th scope="row">
						</th>

						<td id="alexandria-image-uploader-preview">

							<?php if($image = wp_get_attachment_image_src(@$quiz->image_id)) { ?>

								<a href="#" class="upload-custom-img">

									<div id='image-preview' class='alexandria-image-preview-wrapper'>

										<div class="badge">
											<a class="badge-link delete-custom-badge" href="#">X</a>
										</div>

										<img src='<?php echo $image[0] ?>' />

									</div>

								</a>

							<?php } else { ?>

								<div id='image-preview' class='alexandria-image-preview-wrapper hidden'>
									<div class="badge">
										<a class="badge-link delete-custom-badge" href="#">X</a>
									</div>
								</div>

								<div id='image-preview-no-image' class='alexandria-image-preview-wrapper no-image'>
									<span class="preview-text">
										<?php _e('Sin imagen', 'alexandria-mail-builder') ?>
									</span>
								</div>

							<?php } ?>

							<p class="description">
								<?php _e('Imagen destacada del Quizz. Que se muestra en la cabecera de la pagina del Quiz.', 'alexandria-mail-builder') ?>
							</p>
						</td>
					</tr>

					<tr>

						<th scope="row">

							<h3><?php _e('Objetivos del Quizz', 'alexandria-mail-builder')?></h3>

							<p> 
								<input type="button" value="<?php _e('Añadir otro Objetivo', 'alexandria-mail-builder')?>" onclick="alexandriaQuizGameQuizAddObjective();" class="button" />
							</p>

							<input id="numObjectives" type="hidden" name="numObjectives" value="1" />
						</th>

						<td>
							<div id="quizObjectives">
								<?php 

								if(!empty($objectives) and sizeof($objectives)):

									foreach($objectives as $objective):
										include(alexandria_QUIZ_GAME_PLUGIN_PATH."admin/partials/alexandria-mail-builder-objective.php");
									endforeach;

								endif;

								unset($objective);

								include(alexandria_QUIZ_GAME_PLUGIN_PATH."admin/partials/alexandria-mail-builder-objective.php");

								?>
							</div>

						</td>

					</tr>

					<tr>
						<th scope="row">
							<input type="hidden" name="ok" value="1" />
							<input type="submit" name="save" value="<?php _e('Guardar Quiz', 'alexandria-mail-builder')?>" class="button-primary"/>
						</th>
					</tr>

				</tbody>

			</table>

			<?php wp_nonce_field('alexandria_quiz_game_quiz');?>

		</form>

		<div id="title_notice" class="notice notice-error" style="display: none">
			<p><?php _e('Debes indicar un título para el quizz', 'alexandria-mail-builder')?></p>
		</div>

		<div id="thubnail_summary_notice" class="notice notice-error" style="display: none">
			<p><?php _e('La frase de la miniatura no puede superar los 20 palabras.', 'alexandria-mail-builder')?></p>
		</div>

	</div>

	<script type="text/javascript" >

		function alexandriaQuizGameQuizAddObjective() {

			var numObjectives = jQuery('#numObjectives').val();

			html = '<?php ob_start();
			include(alexandria_QUIZ_GAME_PLUGIN_PATH."admin/partials/alexandria-mail-builder-objective-empty.php");
			$content = ob_get_clean();	
			$content = str_replace("\n", '', $content);
			echo $content; ?>';

			numObjectives++;
			jQuery('#numObjectives').val(numObjectives);

			jQuery('#quizObjectives').append(html);
		}

	</script>